// Cycle Spinning Wavelet Shrinkage of the Four Noisy Signals
//
// Here we test an idea of R.R. Coifman, which he calls
// cycle-spinning.  This is a method of removing artifacts
// from wavelet thresholding and other de-noising.
// We apply a specific thresholding rule to the
// four noisy signals depicted in Figure 2.
//
// The procedure for DeNoising:
//       1.  Transform to Wavelet Domain, Using Nearly Symmetric Wavelet
//           with 8 vanishing moments.
//       2.  Apply a soft thresholding nonlinearity, with threshold set to
//           sqrt{2 log(n)}
//       3.  Transform back to the signal domain.
// 
//  We do this at each of 16 circulant shifts of a signal and
//  then average the results.
//  
//  Errors are compared with applying this algorithm at one single shift.
//
//  Remark: run TourInit and toufig0[12] before this.
//
//  Agenda:  Compare Hard Thresholding
//           Compare ordinary VisuShrink
//

//
function versaplot(subp,xarg,yarg,parg,tit,ax,hld)
// versaplot -- Version-independent plot routine
//  Usage
//    versaplot(subp,xarg,yarg,parg,tit,ax,hld)
//  Inputs
//    subp   vector to be supplied to subplot. ignored if empty.
//    xarg   vector to be supplied to subplot. ignored if empty
//    yarg   vector to be supplied to subplot. REQUIRED.
//    parg   character string to be supplied to plot. 
//    tit    vector to be supplied to title. ignored if empty.
//    ax     vector to be supplied to axis. ignored if empty.
//    hld    if not empty, sign(hld) dictates call either to
//           hold off(-1) or on(1).
//
//  Side Effects
//    If subp is not empty, the plot is made in the indicated
//    subplot window.  The plot is of yarg versus xarg, or, if
//    xarg is empty, of yarg against 1:length(yarg).  The plot is
//    a line plot, or, if parg is not empty, a scatterplot with
//    character parg.  If tit is nonempty, the title is set to tit. 
//    If ax is nonempty, the axes are set to ax; if hld is nonempty,
//    the plot is held (hld ==1) or released (hld == 0) afterwards.
// 
//    The method used to perform these actions works under both v3.5
//    and v4.0 of MATLAB.
//
//  See Also
//    Scripts in Adapt, Blocky, Ideal, and Tour
//    MATLABVERSION
//
if ~isempty(subp),
    subplot(subp);
end

if ~isempty(xarg),
   if ~isempty(parg),
       plot(xarg,yarg,parg);
   else
       plot(xarg,yarg);
   end
else
   if ~isempty(parg),
       plot(yarg,parg);
   else
       plot(yarg);
   end
end
if ~isempty(tit),
    title(tit);
end
if ~isempty(ax),
       a=gca();a.data_bounds=(ax);
end;

    
endfunction


	     N = 2048;

	     rho = 7;

	      alf = .9;

	t = (0:(N-1))/N;

	disp('Initializing Parameters:')
	disp(sprintf('N = %g',N))
	disp(sprintf('rho = %g',rho))
	disp(sprintf('alf = %g',alf))

	HeaviSine = MakeSignal('HeaviSine',N);
	Bumps     = MakeSignal('Bumps',N);
	Blocks    = MakeSignal('Blocks',N);
	Doppler   = MakeSignal('Doppler',N);

	[xblocks,yblocks] = NoiseMaker(Blocks,rho);
	[xbumps,ybumps]   = NoiseMaker(Bumps,rho);
	[xheavi,yheavi]   = NoiseMaker(HeaviSine,rho);
	[xDoppler,yDoppler] = NoiseMaker(Doppler,rho);

	QMF_Filter = MakeONFilter('Symmlet',8);
	L = 5;
//
	[xhblocks]  = zeros((yblocks));
	[xhbumps]   = zeros((ybumps   ));
	[xhheavi]   = zeros((yheavi   ));
	[xhDoppler] = zeros((yDoppler));
//
	nxblocks  = 0;
	nxbumps   = 0;
	nxheavi   = 0;
	nxDoppler = 0;
	FirstOnly = 1;
//
	nspin =16;
	for i=0:(nspin-1),		
		[chblocks]  = cyclespin(yblocks,  i);
		[chbumps]   = cyclespin(ybumps,   i);
		[chheavi]   = cyclespin(yheavi,   i);
		[chDoppler] = cyclespin(yDoppler, i);
//
		[dhblocks]  = WaveShrink(chblocks,  'Visu',L,QMF_Filter);
		[dhbumps]   = WaveShrink(chbumps,   'Visu',L,QMF_Filter);
		[dhheavi]   = WaveShrink(chheavi,   'Visu',L,QMF_Filter);
		[dhDoppler] = WaveShrink(chDoppler, 'Visu',L,QMF_Filter);
//
		[dhblocks]  = cyclespin(dhblocks,  -i);
		[dhbumps]   = cyclespin(dhbumps,   -i);
		[dhheavi]   = cyclespin(dhheavi,   -i);
		[dhDoppler] = cyclespin(dhDoppler, -i);
//
		[xhblocks]  = xhblocks  + dhblocks;
		[xhbumps]   = xhbumps   + dhbumps;
		[xhheavi]   = xhheavi   + dhheavi;
		[xhDoppler] = xhDoppler + dhDoppler;
//
		if i==0,
			[zblocks]  = dhblocks;
			[zbumps]   = dhbumps;
			[zheavi]   = dhheavi;
			[zDoppler] = dhDoppler;
		end
//
		if i==0 | (i > 0 & ~FirstOnly),
			nxblocks = nxblocks  + norm(dhblocks-xblocks).^2;
			nxbumps  = nxbumps   + norm(dhbumps-xbumps).^2;
			nxheavi  = nxheavi   + norm(dhheavi-xheavi).^2;
			nxDoppler= nxDoppler + norm(dhDoppler-xDoppler).^2;
		end
//
	end
//
	[xhblocks]  = xhblocks/nspin;
	[xhbumps]   = xhbumps/nspin;
	[xhheavi]   = xhheavi/nspin;
	[xhDoppler] = xhDoppler/nspin;
//
	if FirstOnly, Denom=1; else, Denom=nspin; end
	nxblocks = sqrt(nxblocks/Denom);
	nxbumps  = sqrt(nxbumps/Denom);
	nxheavi  = sqrt(nxheavi/Denom);
	nxDoppler= sqrt(nxDoppler/Denom);
//
	if FirstOnly, 
		labelstr = 'RMS(Orig)'; 
	else, 
		labelstr = 'Root(Ave(MSE(Shifted)))';
	end
//
	printf('Blocks:    RMS(CSpin) =%g %s = %g \n',norm(xhblocks-xblocks),labelstr,nxblocks)
	printf('Bumps :    RMS(CSpin) =%g %s = %g \n',norm(xhbumps-xbumps),labelstr,nxbumps)
	printf('HeaviSine: RMS(CSpin) =%g %s = %g \n',norm(xhheavi-xheavi),labelstr,nxheavi)
	printf('Doppler:   RMS(CSpin) =%g %s = %g \n',norm(xhDoppler-xDoppler),labelstr,nxDoppler)
//
	scf(1);clf()
	versaplot(221,t,xhblocks, [],'  (a) CycleSpin[yBlocks] '   ,[],[])
	versaplot(222,t,xhbumps,  [],'  (b) CycleSpin[yBumps] '    ,[],[])
	versaplot(223,t,xhheavi,  [],'  (c) CycleSpin[yHeaviSine] ',[],[])
	versaplot(224,t,xhDoppler,[],'  (d) CycleSpin[yDoppler] '  ,[],[])
	scf(2);clf();
	versaplot(221,t,xhblocks-xblocks,  [],'  (a) errors:CycleSpin[yBlocks] '   ,[],[])
	versaplot(222,t,xhbumps-xbumps ,   [],'  (b) errors:CycleSpin[yBumps] '    ,[],[])
	versaplot(223,t,xhheavi-xheavi ,   [],'  (c) errors:CycleSpin[yHeaviSine] ',[],[])
	versaplot(224,t,xhDoppler-xDoppler,[],'  (d) errorsd:CycleSpin[yDoppler] '  ,[],[])
//
	scf(3);clf();
	versaplot(221,t,zblocks, [],'  (a) VisuShrink[yBlocks] '   ,[],[])
	versaplot(222,t,zbumps,  [],'  (b) VisuShrink[yBumps] '    ,[],[])
	versaplot(223,t,zheavi,  [],'  (c) VisuShrink[yHeaviSine] ',[],[])
	versaplot(224,t,zDoppler,[],'  (d) VisuShrink[yDoppler] '  ,[],[])
	scf(4);clf();
	versaplot(221,t,zblocks-xblocks,  [],'  (a) errors:VisuShrink[yBlocks] '   ,[],[])
	versaplot(222,t,zbumps-xbumps ,   [],'  (b) errors:VisuShrink[yBumps] '    ,[],[])
	versaplot(223,t,zheavi-xheavi ,   [],'  (c) errors:VisuShrink[yHeaviSine] ',[],[])
	versaplot(224,t,zDoppler-xDoppler,[],'  (d) errorsd:VisuShrink[yDoppler] '  ,[],[])
    
// Revision History
//       10/1/05     AM     The name of the varibale QMF is changed to
//                           QMF_Filter

    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:42 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
