function awt = AWT(x,nvoice,Name,sigma2,par2)
// Analytical Wavelet Transform
//  Calling Sequence
//    awt = AWT(x,nvoice,Name,sigma2,par2);
//  Parameters
//  Inputs:
//    x	   :  signal, could be complex
//    nvoice:  number of voices      default = 12
//    Name  :  Type of Window function, so far only "Gaussian" window available
//    sigma2 :   first parameter, for Gaussian window, it could be variance,  default = 1
//   par2   : another parameter, for Gaussian, it's xi(shifting frequency)   default = 5
//  Outputs:
//    awt   :  Analytical wavelet transform of x
//  Description
//    Coarsest scale is '2', finest scale is (log2(n)-5);
//    awt is a n by nscale matrix;
//     
//  Examples
//    n = 1024;
//    t = ((1:n)./n - .5).*%pi;
//    f = exp(%i*t.^2);
//    awt = AWT(f);
//    ImageCWT(awt,'Individual','hot');
//    ix = [((n/2+1):n),(1:n/2)];
//    plot(abs(awt(ix,1)))	// should looks Gaussian
//    plot(abs(awt(ix,13)))	// should looks Gaussian
//    plot(abs(awt(ix,25)))	// should looks Gaussian
//  See Also
//    ImageCWT
//  Bibliography
//    Mallat, "A Wavelet Tour of Signal Processing";
//             4.4.3 Analytical Wavelet Transform
// Authors
// Copyright (c) 1996. Xiaoming Huo
//  H. Nahrstaedt - 2011

  n = max(size(x));
[lhs,rhs]=argn();
// set default values
  if  rhs < 4,
	sigma2 = 1; xi = 5;
  end;
 if  rhs < 3,
	Name = 'Gabor';
  end;
 if  rhs < 2,
 	nvoice = 12;
  end;

// Fourier Transform of signal
  dftx = mtlb_fft(x(:));
  omega   = [ (0: (n/2)) (((-n/2)+1):-1) ].* (2*%pi/n);

  noctave = floor(log2(n))-4;
  nscale  = nvoice .* noctave;

  awt = zeros(n,nscale);

  kscale  = 1;
  scale   = 2;

  for jo = 1:noctave,
     for jv = 1:nvoice,
        s =  scale .* (2^(jv/nvoice));
        if string(Name)=='Gabor';
        
      	      fre =  (s .* omega  - xi);
              fre = fre(:);
	      omega = omega(:);
	      Psi = realpow(4.*%pi.*sigma2,1/4)*exp(-sigma2/2*fre.*fre);
              Psi = Psi .* bool2s(omega>0);
        end; 
	awt(1:n,kscale) = mtlb_ifft(dftx.*Psi);   
	kscale = kscale + 1;
     end;
     scale  = scale .*2;
  end;
// the matrix awt is ordered from high to low frequencies
endfunction


 
   
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:39 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 