function Ent = CalcEntropy(object,Entropy,par)
// Calculate entropy number of array
//  Calling Sequence
//    Ent = CalcEntropy(object,ent[,par])
//   Parameters
//  Inputs:
//    object:   1-d or 2-d object
//    ent   :   type of entropy to use: options are
//           ent =  'Entropy': -- Coifman-Wickerhauser
//           ent =  'Log'    : -- sum log(|th_i|)
//           ent =  'l^p'    : -- sum |th_i|^p, 0 < p < 2, p = par
//           ent =  'N(eps)' : -- #>= eps, eps = par
//           ent =  'Risk'   : -- sum min(th_i^2,eps^2), eps=par
//           ent =  'Sum'    : -- sum th_i
//           ent =  'SURE'   : -- SURE(Thresholding), thresh = par
//    par   :   extra parameter, depends on type of entropy
//  Outputs:
//    Ent   :   Entropy of object
//
//  Description
//    It is traditional to normalize the object to norm 1 before
//    calling this routine.  This routine does NO pre-scaling.
//
//  See also
//    Calc2dStatTree
//   Authors
// Copyright (c) 1993-5, Jonathan Buckheit and David Donoho
// 
//H. Nahrstaedt - 2011

	if (Entropy=='Entropy'),
		p = (object(:) ).^2;
		Ent = - sum(sum(p .* log(eps+p)));
	elseif (Entropy=='Log')
		p = abs(object(:) );
		Ent = sum(log(eps+p));
	elseif (Entropy=='l^p'),
		// par = p = exponent
		p = abs(object(:) );
		Ent = sum(p .^par);
	elseif (Entropy=='N(eps)'),
		// par = eps
		p = abs(object(:));
		Ent = sum( p > par );
	elseif (Entropy=='Risk'),
		p = object(:).^2;
		Ent = sum(mtlb_min(p,par^2));
	elseif (Entropy=='Sum'),
		p = object(:);
		Ent = sum(p);
	elseif (Entropy=='SURE'),
		tt = par^2;  // par = threshold
		dim = max(size(object(:)));
		p = object(:).^2;
		ngt = sum( p > tt);
		nlt = dim - ngt;
		slt = sum( p .* bool2s( p <= tt )); 
		Ent = dim - 2*nlt + tt*ngt + slt;
	else
		disp('in CalcEntropy: unknown Entropy request')
		printf('Request=<<%s>>\n',Entropy)
		disp('I only know how to do:')
		disp(' Entropy, Log, l^p, N(eps), Risk, SURE ')
	end


endfunction
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:41 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
