function fldx = FoldMeyer(x,sympts,polarity,Window,deg)
// Fold a vector onto itself using a specified window
//  Calling Sequence
//    fldx = FoldMeyer(x, sympts, polarity, Window,deg)
//  Parameters
//  Inputs:
//    x   :     signal vector in frequency domain  (typically of length n=2^J)
//    sympts:    symmetry points, of the form [a,b]
//    polarity:  string selection folding polarity
//             polarity=    'mp':  =>  (-,+) '
//             polarity=     'pm':  =>  (+,-) '
//             polarity=     'mm':  =>  (-,-) '
//             polarity=     'pp':  =>  (+,+) '
//    Window  :  string selecting window
//             Window=    'm': => Mother Meyer Wavelet Window
//             Window=    't': => Truncated Mother Meyer Wavelet Window
//             Window=    'f': => Father Meyer Wavelet Window
//    deg      : degree of Meyer window
//
//  Outputs :
//    fldx   :   folded version of x. Supported on interval [sympts(1),sympts(2)]
//
//  See also
//    WindowMeyer
//    CoarseMeyerCoeff
//    DetailMeyerCoeff
//    FineMeyerCoeff
//  Authors
//  Prepared for the thesis of Eric Kolaczyk, Stanford University, 1994
//  Copyright (c) Eric Kolaczyk, 1994.
//  H. Nahrstaedt - 2011

pio2 = %pi/2;

// **  Window 'x' with the specified window.

	if (Window == 'm') ,
	  eps    = floor(sympts(1)/3);
	  epsp   = sympts(1) - eps - 1;
	  lftind  = [ sympts(1)-eps+1 : sympts(1) ];
	  lmidind = [ sympts(1)+2 : sympts(1)+eps+1 ];
	  rmidind = [ sympts(2)-epsp+1 : sympts(2) ];
	  rghtind = [ sympts(2)+2 : sympts(2)+epsp+1 ];
	  Lft  = x(lftind).*sin(pio2*WindowMeyer(3*((lftind-1)/sympts(2))-1,deg));
	  lmid = x(lmidind).*sin(pio2*WindowMeyer(3*((lmidind-1)/sympts(2))-1,deg));
	  rmid = x(rmidind).*cos(pio2*WindowMeyer((3/2)*((rmidind-1)/sympts(2))-1,deg));
	  rght = x(rghtind).*cos(pio2*WindowMeyer((3/2)*((rghtind-1)/sympts(2))-1,deg));
	
	elseif (Window == 'f') ,
	  n      = max(size(x));
	  eps    = floor(sympts(2)/3);
	  lftind  = [ n + sympts(1) - eps + 1: n + sympts(1) ];
	  lmidind = [ n + sympts(1) + 2 : n + sympts(1) + eps + 1 ];
	  cntrind = [ [n + sympts(1)+ eps + 2: n] [ 1 : sympts(2) -  eps ]  ];
	  rmidind = [ sympts(2) - eps + 1: sympts(2) ];
	  rghtind = [ sympts(2) + 2: sympts(2) + eps + 1 ];
	  Lft  = x(lftind).* ...
			 cos(pio2*WindowMeyer(3*(abs(lftind-n-1)/(2*sympts(2))) - 1,deg));
	  lmid = x(lmidind).* ...
			 cos(pio2*WindowMeyer(3*(abs(lmidind-n-1)/(2*sympts(2)))-1,deg));
	  cntr = x(cntrind);
	  rmid = x(rmidind).* ...
			 cos(pio2*WindowMeyer(3*((rmidind-1)/(2*sympts(2)))-1,deg));
	  rght = x(rghtind).* ...
			 cos(pio2*WindowMeyer(3*((rghtind-1)/(2*sympts(2)))-1,deg));
	
	elseif (Window == 't') ,
	  eps    = floor(sympts(1)/3);
	  epsp   = sympts(1) - eps - 1;
	  lftind  = [ sympts(1)-eps+1 : sympts(1) ];
	  lmidind = [ sympts(1)+2 : sympts(1)+eps+1 ];
	  rmidind = [ sympts(2)-epsp+1 : sympts(2) ];
	  Lft  = x(lftind).*sin(pio2*WindowMeyer(3*((lftind-1)/sympts(2))-1,deg));
	  lmid = x(lmidind).*sin(pio2*WindowMeyer(3*((lmidind-1)/sympts(2))-1,deg));
	  rmid = x(rmidind);
	  rght = zeros(1,max(size(rmidind)));
	else 
	  error(' Either the mother or truncated mother Meyer wavelets  must be used with the polarity chosen.     ');
	end


//** Fold according to the specified polarity.

	if (polarity == 'mp') ,
	  fldx =  [ -fliplr(Lft)   fliplr(rght)      0        ] ...
			+ [     lmid          rmid     x(sympts(2)+1) ];
	elseif (polarity == 'pm') ,
	  fldx =  [      0         fliplr(Lft)  -fliplr(rght) ] ...
			+ [ x(sympts(1)+1)    lmid          rmid      ];
	elseif (polarity == 'pp') ,
	  fldx =  [ x(n+sympts(1)+1) lmid cntr rmid x(sympts(2)+1) ] ...
			+ [ 0 fliplr(Lft) zeros(1,max(size(cntrind))) fliplr(rght) 0 ];
	elseif (polarity == 'mm') ,
	  fldx   =  [ lmid    cntr     rmid  ] ...
			  + [ -fliplr(Lft) zeros(1,max(size(cntrind))) -fliplr(rght)  ];
	else 
	  error(sprintf('Polarity convention must be one of the following !\n ...
	   mp  =>  (-,+) \n ...
	   pm  =>  (+,-) \n ...
	   mm  =>  (-,-) \n ...
	   pp  =>  (+,+) '));
	end
	

//
endfunction
//
 
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:40 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
