function aftf = TFDist_AF(sig)
// Alias-Free Generalized Discrete Time-Frequency Distribution
//  Calling Sequence
//    aftf = TFDist_AF(sig)
//  Parameters
//  Inputs:
//    sig  :   1-d signal of dyadic length n=2^J
//  Outputs:
//    aftf  :  complex-valued matrix representing the alias-free generalized   time-frequency distribution of zero-extended signal with rows   corresponding to frequencies and columns corresponding to times
//
//  Description
//    Image Plot of the alias free TF distribution
//
//  See also
//   WignerDist
//   Spectrogram
//   ImagePhasePlane
//
//  Bibliography
//   Jechang Jeong and William J. Williams,
//   "Alias-Free Generalized Discrete-Time Time-Frequency Distribution
//   IEEE Transactions on Signal Processing", vol. 40, pp. 2757-2765
// 
// Authors
// Copyright (c) 1994-5, Shaobing Chen
//H. Nahrstaedt - 2011

sig = sig(:);
n   = max(size(sig));
f   = [zeros(n,1); sig; zeros(n,1)];
aftf = zeros(sig);
zerosn = zeros(n,1);

for t=1:n,
  x = zerosn;
  for k = 0:(n/2-1),
    // even indices
    if k == 0,
      x(2*k+1) = f(n + t) * f(n+t);
    else
      ix = (-k):k;
      tplus    = n + t + k - ix;
      tminus   = n + t - k - ix;
      ff = f(tplus) .* f(tminus);
      b = 1/((2*k+1)*.54 + .46 * ...
	real((exp(%i*2*%pi*(k+1)/(2*k))-exp(-%i*%pi))/ ...
	(1 - exp(%i*%pi/k))));
      x(2*k+1) = b*(.54+.46*cos(2*%pi*ix/(2*k))) * ff;
    end
    
    // odd indices
    ix = (-k):(k+1);
    tplus = n + t + k - ix + 1;
    tminus   = n + t - k - ix;
    ff = f(tplus) .* f(tminus);
    b = 1/((2*k+2)*.54 + .46 * ...
      real((exp(%i*2*%pi*(k+2)/(2*k+1)) ...
      -exp(-%i*2*%pi*k/(2*k+1))) * exp(-%i*%pi/(2*k+1))/ ...
      (1 - exp(%i*2*%pi/(2*k+1)))));
    x(2*k+2) = b*(.54+.46*cos(2*%pi*(ix-.5)/(2*k+1)))*ff;
  end
//  aftf(:,t) = 2 * real(fft(x));
  aftf(:,t) = 2 * real(fftshift(mtlb_fft(x)));
end

// abstf = abs(aftf);
abstf = aftf;
tfmax = max(max(abstf));
tfmin = min(min(abstf));

mtlb_image(linspace(0,1,n),linspace(0,1,n),255*(abstf-tfmin)/(tfmax-tfmin)+1);
F=gcf();F.color_map(1-graycolormap(256));
title('Alias Free Time-Frequency Distribution');
xlabel('Time')
ylabel('Frequency')


endfunction
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:43 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 
