function [wp, btree] = WPTour(Format,x,D,qmf,titlestr)
// Wavelet packet decomposition and Best Basis analysis
//  Calling Sequence
//    [wp, btree] = WPTour(Format,x,D,qmf,title)
//   Parameters
//  Inputs  :
//    Format : string: 'S' for sequential display of four figures   'P' for four-panel display  
//    x     :  1-d signal to analyze by Wavelet Packets
//    D     :  fineness of frequency splitting
//    qmf   .  quadrature mirror filter (e.g. Coiflet c3)
//    title :  name of signal
//  Outputs:
//    wp    :  Wavelet packet table (see WPAnalysis)
//    btree :  basis tree of best time-frequency basis
//
//  Description
//    The format string controls whether all four displays
//    are drawn as subplots in one figure, or whether they are
//    drawn one-after-the-other on the same figure
//
//    The global PREFERIMAGEGRAPHICS controls whether the phase
//    portrait is done using image graphics (if =1) or plot
//    graphics (if =0).
//
//  Side Effects
//    plot of Wavelet packet Table
//    tree plot, best basis
//    phase plot, best basis
//    printout, entropy, best basis
//
//  See also
//    WPAnalysis
//    BestBasis
//    PlotPhasePlane
//    PlotBasisTree
//
// Authors
// Copyright (c) 1993. David L. Donoho
// H. Nahrstaedt - 2011

	global PREFERIMAGEGRAPHICS
	if ~exists('PREFERIMAGEGRAPHICS'),   
	   PREFERIMAGEGRAPHICS = 0;
	end

	wp = WPAnalysis(x,D,qmf);

	clf();
	if part(Format,1)=='P',
		subplot(221)
	end

	PlotPacketTable(wp);
	signaltitle = [ 'Wavelet Packet Analysis ' +titlestr];
	title(signaltitle); ylabel('Split Level'); xlabel('Frequency[Time]');

	if part(Format,1)=='S',
	    HitAnyKey()
	end

	stree = CalcStatTree(wp,'Entropy');
	[btree,vtree] = BestBasis(stree,D);

	if part(Format,1)=='P',
	    subplot(222)
	end

	signaltitle = [' WP Best Basis; ' +titlestr];
	PlotBasisTree(btree,D,stree,signaltitle);
	xlabel('Frequency Domain Splits');     
	ylabel('Entropy Gain');

	if part(Format,1)=='S',
	    HitAnyKey()
	end

	if part(Format,1)=='P',
	    subplot(223)
	end

//	PlotPhaseTiling('WP',btree,wp,signaltitle);
	wpcoef = UnpackBasisCoeff(btree,wp);
	PlotCompressNumbers(wpcoef,signaltitle);


	if part(Format,1)=='S',
	    HitAnyKey()
	end

	if part(Format,1)=='P',
	    subplot(224)
	end

	if PREFERIMAGEGRAPHICS,
	     ImagePhasePlane('WP',btree,wp,signaltitle,256,qmf)
	else 
	     PlotPhasePlane('WP',btree,wp,signaltitle)
	end

	if part(Format,1)=='S',
	    HitAnyKey()
	end
	endfunction



    
    
    
 
 
//
//  Part of Wavelab Version 850
//  Built Tue Jan  3 13:20:41 EST 2006
//  This is Copyrighted Material
//  For Copying permissions see COPYING.m
//  Comments? e-mail wavelab@stat.stanford.edu 

